@@ -44,7 +44,7 @@ from io import BytesIO
 
 # Logging
 import logging
-from utils.log import log_config
+from cloudgeass.utils.log import log_config
 
 
 """
